@@ -183,6 +183,29 @@ pub const SRGB_FROM_XYZ_MATRIX: [[f32; 3]; 3] = {inverse};
     let s0 = calc_gamma_threshold::<f64>();
     let e0 = gamma_compress_lin_part(&s0);
 
+    /* 512 bits of precision is a massive overkill but whatever, we don’t care
+     * about speed and having too much precision won’t hurt. */
+    let fl = |v| rug::Float::with_val(512, v);
+    let u8_to_linear = (0..=255)
+        .map(|v| {
+            if v <= (e0 * 255.0) as u8 {
+                fl(v as u32 * 10) / fl(32946)
+            } else {
+                let v = fl(v as u32 * 1_000 + 55 * 255) / fl(1055u32 * 255);
+                let e = fl(24) / fl(10);
+                rug::ops::Pow::pow(v, e)
+            }
+        })
+        .map(|v| {
+            /* Make sure zero is encoded as `0.0` so it’s parsed as a floating
+             * point number and not integer.  Normally, to_str_radix() does not
+             * include the decimal separator when formatting zero. */
+            let v = v.to_string_radix(10, Some(24));
+            format!("    {},\n", if v == "0" { &"0.0" } else { &v[..] })
+        })
+        .collect::<Vec<_>>()
+        .join("");
+
     write_to(
         &out_dir,
         "gamma_constants.rs",
@@ -210,8 +233,12 @@ pub const S_0: f32 = {:.};
 /// In theory it’s also an argument at which both parts produce the same result
 /// though that’s subject to floating-point rounding.
 pub const E_0: f32 = {:.};
+
+const U8_TO_LINEAR_LUT: [f32; 256] = [
+{}
+];
 ",
-            s0, e0
+            s0, e0, u8_to_linear
         ),
     )
 }
